==> systemd-kcm-0.7.0.tar.xz: kcmsystemd-0.7.0/src/helper/helper.h <==
/*******************************************************************************
 * Copyright (C) 2013-2014 Ragnar Thomsen <rthomsen6@gmail.com>                *
 *                                                                             *
 * This program is free software: you can redistribute it and/or modify it     *
 * under the terms of the GNU General Public License as published by the Free  *
 * Software Foundation, either version 3 of the License, or (at your option)   *
 * any later version.                                                          *
 *                                                                             *
 * This program is distributed in the hope that it will be useful, but WITHOUT *
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       *
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    *
 * more details.                                                               *
 *                                                                             *
 * You should have received a copy of the GNU General Public License along     *
 * with this program. If not, see <http://www.gnu.org/licenses/>.              *
 *******************************************************************************/

#ifndef HELPER_H
#define HELPER_H

#include <kauth.h>
using namespace KAuth;

class Helper : public QObject
{
  Q_OBJECT
  public slots:
    ActionReply save(QVariantMap args);
    ActionReply dbusaction(QVariantMap args);
};

#endif

==> systemd-kcm-1.1.0.tar.xz: kcmsystemd-1.1.0/src/helper/helper.h <==
/*******************************************************************************
 * Copyright (C) 2013-2015 Ragnar Thomsen <rthomsen6@gmail.com>                *
 *                                                                             *
 * This program is free software: you can redistribute it and/or modify it     *
 * under the terms of the GNU General Public License as published by the Free  *
 * Software Foundation, either version 3 of the License, or (at your option)   *
 * any later version.                                                          *
 *                                                                             *
 * This program is distributed in the hope that it will be useful, but WITHOUT *
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       *
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    *
 * more details.                                                               *
 *                                                                             *
 * You should have received a copy of the GNU General Public License along     *
 * with this program. If not, see <http://www.gnu.org/licenses/>.              *
 *******************************************************************************/

#ifndef HELPER_H
#define HELPER_H

#include <KAuth/kauth.h>
// #include <kauthaction.h>
using namespace KAuth;

class Helper : public QObject
{
  Q_OBJECT
  public Q_SLOTS:
    ActionReply save(const QVariantMap& args);
    ActionReply dbusaction(const QVariantMap& args);
};

#endif
